@@ -240,8 +240,7 @@ class ContainerAnalysisGrpcTransport(ContainerAnalysisTransport):
 
     @property
     def grpc_channel(self) -> grpc.Channel:
-        """Return the channel designed to connect to this service.
-        """
+        """Return the channel designed to connect to this service."""
         return self._grpc_channel
 
     @property
@@ -384,5 +383,9 @@ class ContainerAnalysisGrpcTransport(ContainerAnalysisTransport):
     def close(self):
         self.grpc_channel.close()
 
+    @property
+    def kind(self) -> str:
+        return "grpc"
+
 
 __all__ = ("ContainerAnalysisGrpcTransport",)
